@@ -1,7 +1,7 @@
 
 import requests
 
-BASE_URL = 'https://ec2-54-209-240-53.compute-1.amazonaws.com:8080/'
+BASE_URL = 'https://ec2-54-209-240-53.compute-1.amazonaws.com:8080'
 
 def get_coin_data(ticker: str):
     
